#!/usr/bin/env node

/**
 * This script contains the migration CLI
 *  - It is used to migrate data from one database to another
 * mmdb --source <source_url> --target <target_url> --src_db <src_db> --target_db <target_db> --collections <collections> --query <query>
 */

const { Command } = require("commander");
const program = new Command();
const pkg = require("../package.json");
// const migrate = require("./migrate").migrate;

program
  .version(pkg.version)
  .description("Migrate data from one database to another")
  .option("-s, --source <source_url>", "source url [required]")
  .option("-t, --target <target_url>", "target url [required]")
  .option("-sdb, --src_db <src_db>", "source database [required]")
  .option("-tdb, --target_db <target_db>", "target database")
  .option("-c, --collection <collection>", "collection to copy")
  .option("-u, --username <username>", "username")
  .option("-p, --password <password>", "password")
  .option("-q, --query <query>", "query")
  .action(async (options) => {
    if(!options.source || !options.target || !options.src_db || !options.target_db || !options.username || !options.password){
        console.log("Please provide all the required options\n");
        //  show the help
        program.help();
        return;
    }

    if(!options.source || !options.target || !options.src_db ){
        console.log("Please provide all the required options --source, --target, --src_db");
        program.help();
        return;
    }
    
    await migrate(
      options.source,
      options.target,
      options.src_db,
      options.target_db,
      options.username,
      options.password,
      options.collection,
      options.query
    );
  });

program.parse(process.argv);

// const options = program.opts();

// migrate(options.source, options.target, options.src_db, options.target_db, options.collections, options.query);
